@@ -14,9 +14,7 @@ parent_type(::Type{FqFieldElem}) = FqField
 
 elem_type(::Type{FqField}) = FqFieldElem
 
-base_ring_type(::Type{FqField}) = typeof(Union{})
-
-base_ring(a::FqField) = Union{}
+base_ring_type(::Type{FqField}) = Union{}
 
 parent(a::FqFieldElem) = a.parent
 
