@@ -542,7 +542,7 @@ function (a::fqPolyRepMPolyRingElem)(vals::Integer...)
   return evaluate(a, [vals...])
 end
 
-function (a::fqPolyRepMPolyRingElem)(vals::Union{NCRingElem, RingElement}...)
+function (a::fqPolyRepMPolyRingElem)(vals::NCRingElement...)
   length(vals) != nvars(parent(a)) && error("Number of variables does not match number of values")
   R = base_ring(a)
   # The best we can do here is to cache previously used powers of the values
