@@ -588,7 +588,7 @@ for (etype, rtype, ftype, ctype, utype) in (
       return evaluate(a, [vals...])
     end
 
-    function (a::($etype))(vals::Union{NCRingElem, RingElement}...)
+    function (a::($etype))(vals::NCRingElement...)
       length(vals) != nvars(parent(a)) && error("Number of variables does not match number of values")
       R = base_ring(a)
       # The best we can do here is to cache previously used powers of the values
